==> validaRA_0.1.0.tar.gz: validaRA/inst/doc/validaRA.R <==
## ---- include=FALSE-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
options(width = "800")

## ---- results='asis', echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

CPF <- c(5,6,2,7,3,8,6,9,5,9,6)

VV1 <- c(10,9,8,7,6,5,4,3,2,0,0)

RES1 <- CPF * VV1

m <- matrix(c(CPF, VV1, RES1), ncol = 11, byrow = T)
rownames(m) <- c("CPF: ", "VV 1: ", "RES: ")
knitr::kable(m)

## ---- results='asis', echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

CPF <- c(5,6,2,7,3,8,6,9,5,9,6)

VV2 <- c(11, 10,9,8,7,6,5,4,3,2,0)

RES1 <- CPF * VV2

m <- matrix(c(CPF, VV1, RES1), ncol = 11, byrow = T)
rownames(m) <- c("CPF: ", "VV 2: ", "RES 2: ")
knitr::kable(m)

## ---- results='asis', echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

VV <- c(3, 2,9,8,7,6,5,4,3,2,0)

m <- matrix(VV, ncol = 11, byrow = T)
rownames(m) <- c("VV: ")
knitr::kable(m)

## ---- results='asis', echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

VV <- c(5, 4, 3, 2, 9, 8, 7, 6, 5, 4, 3, 2, 0, 0)
VV2 <- c(6, 5, 4, 3, 2, 9, 8, 7, 6, 5, 4, 3, 2, 0)
m <- matrix(c(VV, VV2), ncol = 14, byrow = T)
rownames(m) <- c("VV1: ", "VV2: ")
knitr::kable(m)

## ---- results='asis', echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

VV <- c(15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 1)

m <- matrix(VV, ncol = 15, byrow = T)
rownames(m) <- c("V1: ")
knitr::kable(m)

## ---- results='asis', echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

VV <- c(15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 0, 0, 0, 0)

m <- matrix(VV, ncol = 15, byrow = T)
rownames(m) <- c("V1: ")
knitr::kable(m)

## ---- eval=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
#  install.packages("devtools")

## ---- eval=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
#  devtools::install_github("ipea/validaRA")

## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
library("validaRA")

## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
valida_doc("56273869596")

## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
valida_doc("56273869596", type = "pis")

## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
d <- valida_doc("56273869595", type = "pis", log = T)


## ---- echo=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
knitr::kable(d)

## ---- eval=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
#  relatorioDOC(input_file = arquivo.xls, columns = c(CPF, PIS), types = c(cpf, pis),     output_filename = resultado.pdf)

==> validaRA_0.1.1.tar.gz: validaRA/inst/doc/validaRA.R <==
## ---- include=FALSE-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
options(width = "800")

## ---- results='asis', echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

CPF <- c(5,6,2,7,3,8,6,9,5,9,6)

VV1 <- c(10,9,8,7,6,5,4,3,2,0,0)

RES1 <- CPF * VV1

m <- matrix(c(CPF, VV1, RES1), ncol = 11, byrow = T)
rownames(m) <- c("CPF: ", "VV 1: ", "RES: ")
knitr::kable(m)

## ---- results='asis', echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

CPF <- c(5,6,2,7,3,8,6,9,5,9,6)

VV2 <- c(11, 10,9,8,7,6,5,4,3,2,0)

RES1 <- CPF * VV2

m <- matrix(c(CPF, VV1, RES1), ncol = 11, byrow = T)
rownames(m) <- c("CPF: ", "VV 2: ", "RES 2: ")
knitr::kable(m)

## ---- results='asis', echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

VV <- c(3, 2,9,8,7,6,5,4,3,2,0)

m <- matrix(VV, ncol = 11, byrow = T)
rownames(m) <- c("VV: ")
knitr::kable(m)

## ---- results='asis', echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

VV <- c(5, 4, 3, 2, 9, 8, 7, 6, 5, 4, 3, 2, 0, 0)
VV2 <- c(6, 5, 4, 3, 2, 9, 8, 7, 6, 5, 4, 3, 2, 0)
m <- matrix(c(VV, VV2), ncol = 14, byrow = T)
rownames(m) <- c("VV1: ", "VV2: ")
knitr::kable(m)

## ---- results='asis', echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

VV <- c(15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 1)

m <- matrix(VV, ncol = 15, byrow = T)
rownames(m) <- c("V1: ")
knitr::kable(m)

## ---- results='asis', echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

VV <- c(15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 0, 0, 0, 0)

m <- matrix(VV, ncol = 15, byrow = T)
rownames(m) <- c("V1: ")
knitr::kable(m)

## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
install.packages("validaRA", repos ="https://vps.fmvz.usp.br/CRAN/")

## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
library("validaRA")

## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
valida_doc("56273869596")

## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
valida_doc("56273869596", type = "pis")

## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
d <- valida_doc("56273869595", type = "pis", log = T)


## ---- echo=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
knitr::kable(d)

## ---- eval=FALSE--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
#  relatorioDOC(input_file = “arquivo.xls”, columns = c(“CPF”, “PIS”), types = c(“cpf”, “pis”),     output_filename = “resultado.pdf”)
